@@ -1,13 +1,10 @@
 from staremaster.products.mod05 import MOD05
 from staremaster.products.mod09 import MOD09
-from staremaster.products.vnp03 import VNP03
-from staremaster.products.vnp02dnb import VNP02DNB
-from staremaster.products.vj102dnb import VJ102DNB
-from staremaster.products.vj103 import VJ103
-from staremaster.products.cldmsk_l2_viirs import CLMDKS_L2_VIIRS
+from staremaster.products.viirsL2 import VNP03MOD, CLMDKS_L2_VIIRS, VNP03IMG
 from staremaster.products.ssmis import SSMIS
 from staremaster.products.atms import ATMS
 from staremaster.products.amsr import AMSR
 from staremaster.products.imerg import IMERG
 from staremaster.products.satcorps import satCORPS
 from staremaster.products.modis_tilegrid import ModisTile
+from staremaster.products.goes_abi_fixed_grid import GOES_ABI_FIXED_GRID
